# NMigen Util 

This project implements utilities for nmigen.  Its development is covered
under an NLNet Grant and the top-level bugreport is here:
http://bugs.libre-riscv.org/show_bug.cgi?id=62

# Requirements

* nmigen
* yosys (latest git repository, required by nmigen)
* pyvcd (for stylish GTKWave documents) - available on Pypi
